DROP TABLE if exists PortsQ;
CREATE TABLE PortsQ (PathId INTEGER PRIMARY KEY, FullPkgPath TEXT, AUTOCONF_VERSION TEXT, AUTOMAKE_VERSION TEXT, BUILD_DEPENDS TEXT, CATEGORIES TEXT, COMES_WITH TEXT, COMMENT TEXT, COMPILER TEXT, COMPILER_LANGS TEXT, COMPILER_LINKS TEXT, CONFIGURE_ARGS TEXT, CONFIGURE_STYLE TEXT, DEBUG_CONFIGURE_ARGS TEXT, DESCR TEXT, DESCR_CONTENTS TEXT, DISTNAME TEXT, DIST_SUBDIR TEXT, DPB_PROPERTIES TEXT, EPOCH TEXT, EXTRACT_FILES TEXT, FIX_CRLF_FILES TEXT, FIX_EXTRACT_PERMISSIONS INTEGER, FLAVORS TEXT, FULLPKGNAME TEXT, GH_ACCOUNT TEXT, GH_COMMIT TEXT, GH_PROJECT TEXT, GH_TAGNAME TEXT, HOMEPAGE TEXT, IGNORE TEXT, IS_INTERACTIVE TEXT, LIB_DEPENDS TEXT, MAINTAINER TEXT, MAKEFILE_LIST TEXT, MODULES TEXT, NOT_FOR_ARCHS TEXT, NO_BUILD INTEGER, NO_TEST INTEGER, ONLY_FOR_ARCHS TEXT, PERMIT_DISTFILES TEXT, PERMIT_PACKAGE TEXT, PKGNAME TEXT, PKGPATHS TEXT, PKGSPEC TEXT, PKGSTEM TEXT, PKG_ARCH TEXT, PORTROACH TEXT, PORTROACH_COMMENT TEXT, PREFIX TEXT, PSEUDO_FLAVOR TEXT, PSEUDO_FLAVORS TEXT, README TEXT, README_CONTENTS TEXT, REVISION TEXT, ROACH_SITES TEXT, ROACH_URL TEXT, RUN_DEPENDS TEXT, SEPARATE_BUILD TEXT, SHARED_LIBS TEXT, SITES TEXT, STATIC_PLIST INTEGER, SUBPACKAGE TEXT, SUBST_VARS TEXT, TARGETS TEXT, TEST_DEPENDS TEXT, TEST_IS_INTERACTIVE TEXT, UNLINKED TEXT, UPDATE_PLIST_ARGS TEXT, USE_GMAKE INTEGER, USE_GROFF INTEGER, USE_LIBTOOL INTEGER, USE_LLD INTEGER, USE_NOBTCFI INTEGER, USE_NOEXECONLY INTEGER, USE_WXNEEDED INTEGER, WANTLIB TEXT);
INSERT INTO PortsQ select * from Ports;
ANALYZE;
